@@ -2,6 +2,8 @@ import threading
 import typing as tp
 from threading import Thread
 
+from satella.exceptions import WouldWaitMore
+
 
 class ThreadCollection:
     """
@@ -18,10 +20,11 @@ class ThreadCollection:
     >>> tc.join()
 
     This also implements iteration (it will return all the threads in the collection) and
-    length check.
+    length check. This also supports + and += operations for all thread collections,
+    threads and iterables of threads.
     """
 
-    __slots__ = ('threads', )
+    __slots__ = 'threads',
 
     def __len__(self):
         return len(self.threads)
@@ -70,8 +73,11 @@ class ThreadCollection:
         for thread in self.threads:
             thread.daemon = v
 
-    def __init__(self, threads: tp.Sequence[Thread]):
-        self.threads = list(threads)
+    def __init__(self, threads: tp.Optional[tp.Sequence[Thread]] = None):
+        if threads is None:
+            self.threads = []
+        else:
+            self.threads = list(threads) or []
 
     def append(self, thread: Thread) -> 'ThreadCollection':
         """
@@ -116,14 +122,21 @@ class ThreadCollection:
                 pass
         return self
 
-    def join(self) -> 'ThreadCollection':
+    def join(self, timeout: tp.Optional[float] = None) -> 'ThreadCollection':
         """
         Join all threads
 
+        :param timeout: maximum time in seconds to wait for the threads to terminate.
+            Note that the timeout will be applied to each thread in sequence, so this
+            can block for up to thread_count*timeout seconds. Default value of
+            None means wait as long as it's necessary.
         :returns: this thread collection instance
+        :raises WouldWaitMore: one of the threads failed to terminate
         """
         for thread in self.threads:
-            thread.join()
+            thread.join(timeout=timeout)
+            if thread.is_alive():
+                raise WouldWaitMore('Thread failed to terminate')
         return self
 
     def is_alive(self) -> bool:
@@ -131,3 +144,32 @@ class ThreadCollection:
         Is at least one thread alive?
         """
         return any(thread.is_alive() for thread in self.threads)
+
+    def __iadd__(self, other: tp.Union['ThreadCollection', Thread, tp.Iterable[Thread]]):
+        """
+        Add a thread collection or a thread to this collection.
+
+        :param other: a ThreadCollection or a Thread to add
+        """
+        if isinstance(other, Thread):
+            other = [other]
+        elif isinstance(other, ThreadCollection):
+            other = other.threads
+        else:
+            other = list(other)
+        self.threads.extend(other)
+        return self
+
+    def __add__(self, other: tp.Union['ThreadCollection', Thread, tp.Iterable[Thread]]):
+        """
+        Add a thread collection or a thread to this collection and return a new collection
+
+        :param other: a ThreadCollection or a Thread to add
+        """
+        if isinstance(other, Thread):
+            other = [other]
+        elif isinstance(other, ThreadCollection):
+            other = other.threads
+        else:
+            other = list(other)
+        return ThreadCollection(self.threads + other)
